@@ -26,13 +26,15 @@ class serialyaml(serial):
         return "safe_load"
 
     def dumpfunc(self) -> str:
-        lines = ['\ndef dump(obj, file):',
-                 f'\t{self.importstring}',
-                 f'\tif isinstance(obj, (set, tuple)):',
-                 f'\t\tobj = list(obj)',
-                 f'\tif not file.endswith("{self.extension}"):',
-                 f'\t\tfile = file + "{self.extension}"',
-                 f'\twith open(file, "{self.write_mode}") as o:',
-                 f'\t\t{self.callstring}.{self.dumpstring}(obj, o)']
+        lines = [
+            f"\ndef {self.dumpfunc_name}(obj, file):",
+            f"\t{self.importstring}",
+            "\tif isinstance(obj, (set, tuple)):",
+            "\t\tobj = list(obj)",
+            f'\tif not file.endswith("{self.extension}"):',
+            f'\t\tfile = file + "{self.extension}"',
+            f'\twith open(file, "{self.write_mode}") as o:',
+            f"\t\t{self.callstring}.{self.dumpstring}(obj, o)",
+        ]
 
-        return '\n'.join(lines)
+        return "\n".join(lines)
