@@ -1,4 +1,4 @@
 from remotemanager.storage.sendablemixin import SendableMixin
 from remotemanager.storage.trackedfile import TrackedFile
 
-__all__ = ['SendableMixin', 'TrackedFile']
+__all__ = ["SendableMixin", "TrackedFile"]
