@@ -1,5 +1,5 @@
+from remotemanager.transport.cp import cp
 from remotemanager.transport.rsync import rsync
 from remotemanager.transport.scp import scp
-from remotemanager.transport.cp import cp
 
-__all__ = ['transport', 'cp', 'rsync', 'scp']
+__all__ = ["transport", "cp", "rsync", "scp"]
